@@ -188,6 +188,7 @@ class Aztp:
                 # Create identity object
                 identity = Identity(
                     aztp_id=aztp_id,
+                    workload_id=identity_info.get("workloadId"),
                     valid=valid,
                     certificate="",
                     private_key="",
@@ -350,8 +351,8 @@ class Aztp:
             if isinstance(result, dict) and 'data' in result:
                 # Remove _id from the response data if it exists
                 data = result['data']
-                if '_id' in data:
-                    del data['_id']
+                # if '_id' in data:
+                #     del data['_id']
 
                 return json.dumps(data, indent=2)
             return result
@@ -371,10 +372,10 @@ class Aztp:
         Returns:
             dict: The identity information
         """
-        if not agent.identity:
+        if not agent.identity.workload_id:
             return None
 
-        workload_id = agent.identity.aztp_id
+        workload_id = agent.identity.workload_id
 
         try:
             response = self.session.get(
